import 'package:flutter/material.dart';

class ControlBar extends StatefulWidget {
  final String title;
  final int selectedIndex;
  final Color textColor;
  final List<ControlBarItem> items;
  final void Function(int)? onTap;

  const ControlBar({
    Key? key,
    this.title = "",
    this.selectedIndex = 0,
    this.textColor = Colors.orange,
    this.items = const [],
    this.onTap,
  }) : super(key: key);

  @override
  _ControlBarState createState() => _ControlBarState();
}

class _ControlBarState extends State<ControlBar> {
  String title = "";
  int selectedIndex = 0;

  @override
  void initState() {
    super.initState();

    setState(() {
      title = widget.title;
      selectedIndex = widget.selectedIndex;
    });
  }

  @override
  Widget build(BuildContext context) {
    return BottomNavigationBar(
      type: BottomNavigationBarType.fixed,
      selectedFontSize: 14,
      fixedColor: widget.textColor,
      currentIndex: selectedIndex,
      unselectedFontSize: 14,
      onTap: (value) {
        if (widget.onTap != null) widget.onTap!(value);

        setState(() {
          selectedIndex = value;
        });
      },
      items: [
        for (var i = 0; i < widget.items.length; i++)
          BottomNavigationBarItem(
            label: widget.items[i].label,
            icon: Image.asset(
              widget.items[i].image,
              color: selectedIndex == i ? widget.textColor : null,
              height: 30,
            ),
          ),
      ],
    );
  }
}

class ControlBarItem {
  final String label;
  final String image;

  ControlBarItem(
    this.label,
    this.image,
  );
}
