import 'package:flutter/material.dart';
import 'package:puma_ui/helpers/urlHelper.dart';
import 'package:puma_ui/ui/atoms/pumaTextButton.dart';

class PumaAboutUS extends StatelessWidget {
  final String website;
  final String subtitle;
  final String logo;
  final Map<String, String> people;

  PumaAboutUS({
    required this.people,
    this.website = "",
    this.subtitle = "",
    this.logo = "logoWID_Color.png",
  });

  Widget build(BuildContext context) {
    return _createBody(context);
  }

  Widget getPersonTile(String name, String job) {
    return Padding(
      padding: const EdgeInsets.only(bottom: 4.0, top: 4.0),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Text(
                name,
                style: TextStyle(color: Colors.black),
              )
            ],
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Text(
                job,
                style: TextStyle(color: Colors.grey),
              )
            ],
          )
        ],
      ),
    );
  }

  _createBody(BuildContext context) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: [
        Padding(
          padding: const EdgeInsets.only(bottom: 12.0, top: 12.0),
          child: Image.asset(
            "lib/assets/$logo",
            height: 60,
          ),
        ),
        Text(
          subtitle,
          textAlign: TextAlign.center,
          style: Theme.of(context).textTheme.headline6!.merge(
                TextStyle(
                  color: Colors.black,
                  fontWeight: FontWeight.w700,
                ),
              ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 24.0),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              for (var person in people.entries)
                getPersonTile(person.key, person.value),
            ],
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Container(
            child: Center(
              child: PumaTextButton(
                text: website,
                color: Colors.blue,
                onPressed: () {
                  launchWebsite(
                    website: website,
                  );
                },
              ),
            ),
          ),
        ),
      ],
    );
  }
}
