import 'package:flutter/material.dart';

class PumaTile extends StatefulWidget {
  final String title;
  final String? subtitle;
  final String? description;
  final bool favorite;
  final bool selected;
  final bool verified;
  final double opacity;
  final Color? textColor;
  final Widget? heading;
  final double? height;
  final IconData trailingIcon;
  final Widget? subtitleWidget;
  final void Function()? onTap;
  final void Function()? onTrailingTap;

  const PumaTile({
    Key? key,
    this.title = "",
    this.subtitle,
    this.description,
    this.favorite = false,
    this.selected = false,
    this.verified = false,
    this.opacity = 1,
    this.textColor,
    this.heading,
    this.height = 72,
    this.trailingIcon = Icons.info_outline,
    this.subtitleWidget,
    this.onTap,
    this.onTrailingTap,
  }) : super(key: key);

  @override
  _PumaTileState createState() => _PumaTileState();
}

class _PumaTileState extends State<PumaTile> {
  String title = "";

  @override
  void initState() {
    super.initState();

    setState(() {
      title = widget.title;
    });
  }

  Widget defaultHeading() {
    if (widget.heading != null) {
      return widget.heading!;
    }
    return Container(
      width: 24,
    );
  }

  Widget titleRow(Color? textColor) {
    return FittedBox(
      fit: BoxFit.scaleDown,
      alignment: Alignment.topCenter,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          if (widget.favorite)
            Padding(
              padding: const EdgeInsets.only(right: 4.0),
              child: Icon(
                Icons.favorite,
                color: Colors.pink,
                size: 14,
              ),
            ),
          Text(
            title,
            style: TextStyle(
              fontWeight: FontWeight.bold,
              fontSize: 16,
              color: textColor,
            ),
          ),
        ],
      ),
    );
  }

  Widget subtitleRow(Color? textColor) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        if (widget.subtitleWidget != null) widget.subtitleWidget!,
        if (widget.subtitle != null)
          Expanded(
            child: Text(
              widget.subtitle!,
              maxLines: 2,
              style: TextStyle(
                color: textColor,
              ),
            ),
          ),
        if (widget.description != null)
          Text(
            widget.description!,
            textAlign: TextAlign.right,
            style: TextStyle(
              color: textColor,
            ),
          )
      ],
    );
  }

  Widget trailing(Color? color) {
    return GestureDetector(
      onTap: widget.onTrailingTap,
      child: Container(
        color: Colors.transparent,
        height: widget.height,
        width: 70,
        child: Icon(
          widget.trailingIcon,
          color: color,
        ),
      ),
    );
  }

  Widget tileRow(BuildContext context) {
    Color? textColor =
        widget.selected ? Theme.of(context).primaryColor : widget.textColor;

    return GestureDetector(
      onTap: widget.onTap,
      child: Container(
        height: widget.height,
        color: Colors.transparent,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Padding(
              padding: const EdgeInsets.only(left: 16.0, right: 22.0),
              child: widget.verified
                  ? Icon(
                      Icons.verified,
                      color: textColor,
                    )
                  : defaultHeading(),
            ),
            Expanded(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  titleRow(textColor),
                  subtitleRow(textColor),
                ],
              ),
            ),
            trailing(textColor),
          ],
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Opacity(
      opacity: widget.opacity,
      child: tileRow(context),
    );
  }
}
