import 'package:flutter/material.dart';
import 'package:flutter_slidable/flutter_slidable.dart';

class SlideItem extends StatelessWidget {
  final Widget child;
  final String valueKey;
  final bool slideable;
  final bool dismissible;
  final String label;
  final IconData? icon;
  final Color color;
  final Color textColor;
  final bool slideLeft;
  final Function()? onAction;

  SlideItem({
    Key? key,
    required this.child,
    required this.valueKey,
    this.slideable = true,
    this.dismissible = true,
    this.label = "",
    this.icon,
    this.color = Colors.blue,
    this.textColor = Colors.white,
    this.slideLeft = true,
    this.onAction,
  }) : super(key: key);

  Widget slideAction() {
    return SlidableAction(
      label: label,
      backgroundColor: color,
      foregroundColor: Colors.white,
      icon: icon,
      onPressed: (e) {
        if (onAction != null) onAction!();
      },
    );
  }

  ActionPane? getActionPane(bool left) {
    if (slideLeft == left)
      return ActionPane(
        extentRatio: 0.5,
        motion: const ScrollMotion(),
        dismissible: (onAction == null || !dismissible)
            ? null
            : DismissiblePane(
                onDismissed: () {
                  onAction!();
                },
              ),
        children: [
          slideAction(),
        ],
      );

    return null;
  }

  Widget build(BuildContext context) {
    if (slideable)
      return Slidable(
        key: ValueKey(valueKey),
        startActionPane: getActionPane(true),
        endActionPane: getActionPane(false),
        child: child,
      );

    return child;
  }
}
