import 'package:flutter/material.dart';

class WhatsNew extends StatelessWidget {
  final List<String> whatsNewContent;
  final String version;
  final String buildNumber;
  final bool rateButton;
  final String rateText;
  final bool dismissButton;
  final String dismissText;
  final void Function()? onDismissed;

  WhatsNew({
    required this.whatsNewContent,
    required this.version,
    required this.buildNumber,
    this.rateButton = true,
    this.rateText = "",
    this.dismissButton = true,
    this.dismissText = "",
    this.onDismissed,
  });

  Widget build(BuildContext context) {
    return _createBody(context);
  }

  _createBody(BuildContext context) {
    final body2 = Theme.of(context)
        .textTheme
        .bodyText2!
        .merge(TextStyle(color: Colors.black));

    final bullet = Padding(
      padding: const EdgeInsets.only(right: 8.0, top: 4),
      child: Icon(
        Icons.circle,
        color: Colors.black,
        size: 8,
      ),
    );

    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      mainAxisSize: MainAxisSize.min,
      children: [
        Padding(
          padding: const EdgeInsets.only(bottom: 8.0),
          child: ClipRRect(
            borderRadius: BorderRadius.circular(12.0),
            child: Image.asset(
              "lib/assets/icon.png",
              height: 60,
            ),
          ),
        ),
        Text(
          version,
          textAlign: TextAlign.center,
          style: Theme.of(context).textTheme.headline4!.merge(
              TextStyle(color: Colors.black, fontWeight: FontWeight.w700)),
        ),
        Text(
          buildNumber,
          textAlign: TextAlign.center,
          style: body2.merge(
            TextStyle(color: Colors.grey.shade700, fontSize: 12),
          ),
        ),
        Divider(),
        Wrap(
          runSpacing: 8,
          children: [
            for (var newContent in whatsNewContent)
              Row(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  bullet,
                  Expanded(
                    child: Padding(
                      padding: const EdgeInsets.only(bottom: 6.0),
                      child: Text(
                        newContent,
                        style: body2,
                      ),
                    ),
                  )
                ],
              ),
          ],
        ),
        if (rateButton)
          Padding(
            padding: const EdgeInsets.only(top: 12.0, bottom: 10.0),
            child: OutlinedButton(
                onPressed: () {
                  //  launchAppStoreReview();
                },
                style: OutlinedButton.styleFrom(
                  backgroundColor: Colors.yellow.shade200,
                  side: BorderSide(
                    width: 1.0,
                    color: Colors.yellow.shade600,
                  ),
                ),
                child: Row(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    Padding(
                      padding: const EdgeInsets.only(right: 8.0),
                      child: Icon(
                        Icons.star,
                        color: Colors.black,
                        size: 16,
                      ),
                    ),
                    Text(
                      rateText,
                      style: body2,
                    ),
                  ],
                )),
          ),
        if (dismissButton)
          Padding(
            padding: const EdgeInsets.only(top: 8.0),
            child: Container(
              width: MediaQuery.of(context).size.width,
              child: ElevatedButton(
                  onPressed: () {
                    Navigator.of(context).pop();
                    if (onDismissed != null) {
                      onDismissed!();
                    }
                  },
                  style: ButtonStyle(
                    backgroundColor: MaterialStateProperty.all(Colors.blue),
                  ),
                  child: Text(
                    dismissText,
                    style: TextStyle(color: Colors.white),
                  )),
            ),
          ),
      ],
    );
  }
}
